@@ -25,6 +25,29 @@ from sklearn.model_selection import GridSearchCV, RandomizedSearchCV, train_test
 
 from zoish.model_conf import Categorical_list, Integer_list
 
+maping_mesurements = {
+    "accuracy_score": accuracy_score,
+    "explained_variance_score": explained_variance_score,
+    "f1": f1_score,
+    "f1_score": f1_score,
+    "mean_absolute_error": mean_absolute_error,
+    "mae": mean_absolute_error,
+    "mean_absolute_percentage_error": mean_absolute_percentage_error,
+    "mape": mean_absolute_percentage_error,
+    "mean_squared_error": mean_squared_error,
+    "mse": mean_squared_error,
+    "median_absolute_error": median_absolute_error,
+    "precision_score": precision_score,
+    "precision": precision_score,
+    "r2": r2_score,
+    "r2_score": r2_score,
+    "recall_score": recall_score,
+    "recall": recall_score,
+    "roc_auc_score": roc_auc_score,
+    "roc": roc_auc_score,
+    "roc_auc": roc_auc_score,
+}
+
 
 def _trail_param_retrive(trial, dict, keyword):
     """An internal function. Return a trial suggest using dict params of estimator and
@@ -255,7 +278,7 @@ def _calc_metric_for_single_output_regression(valid_y, pred_labels, SCORE_TYPE):
 
 
 def _calc_best_estimator_grid_search(
-    X, y, estimator, estimator_params, measure_of_accuracy, verbose, n_jobs, cv
+    X, y, estimator, estimator_params, performance_metric, verbose, n_jobs, cv
 ):
     """Internal function for returning best estimator using
     assigned parameters by GridSearch.
@@ -386,7 +409,7 @@ def _calc_best_estimator_grid_search(
         param_grid=estimator_params,
         cv=cv,
         n_jobs=n_jobs,
-        scoring=make_scorer(measure_of_accuracy),
+        scoring=make_scorer(maping_mesurements[performance_metric]),
         verbose=verbose,
     )
     grid_search.fit(X, y)
@@ -395,7 +418,7 @@ def _calc_best_estimator_grid_search(
 
 
 def _calc_best_estimator_random_search(
-    X, y, estimator, estimator_params, measure_of_accuracy, verbose, n_jobs, n_iter, cv
+    X, y, estimator, estimator_params, performance_metric, verbose, n_jobs, n_iter, cv
 ):
     """Internal function for returning best estimator using
     assigned parameters by RandomSearch.
@@ -531,7 +554,7 @@ def _calc_best_estimator_random_search(
         cv=cv,
         n_iter=n_iter,
         n_jobs=n_jobs,
-        scoring=make_scorer(measure_of_accuracy),
+        scoring=make_scorer(maping_mesurements[performance_metric]),
         verbose=verbose,
     )
     random_search.fit(X, y)
@@ -543,15 +566,20 @@ def _calc_best_estimator_optuna_univariate(
     X,
     y,
     estimator,
-    measure_of_accuracy,
+    performance_metric,
     estimator_params,
     verbose,
     test_size,
     random_state,
-    eval_metric,
-    number_of_trials,
-    sampler,
-    pruner,
+    study,
+    study_optimize_objective,
+    study_optimize_objective_n_trials,
+    study_optimize_objective_timeout,
+    study_optimize_n_jobs,
+    study_optimize_catch,
+    study_optimize_callbacks,
+    study_optimize_gc_after_trial,
+    study_optimize_show_progress_bar,
     with_stratified,
 ):
     """Internal function for returning best estimator using
@@ -756,7 +784,7 @@ def _calc_best_estimator_optuna_univariate(
             dvalid = xgboost.DMatrix(valid_x, label=valid_y)
             param = {}
             param["verbosity"] = verbose
-            param["eval_metric"] = eval_metric
+            # param["eval_metric"] = eval_metric
 
             for param_key in estimator_params.keys():
                 param[param_key] = _trail_param_retrive(
@@ -764,8 +792,13 @@ def _calc_best_estimator_optuna_univariate(
                 )
 
             # Add a callback for pruning.
+        if estimator.__class__.__name__ == "XGBClassifier":
             pruning_callback = optuna.integration.XGBoostPruningCallback(
-                trial, "validation-" + eval_metric
+                trial, "validation-auc"
+            )
+        if estimator.__class__.__name__ == "XGBRegressor":
+            pruning_callback = optuna.integration.XGBoostPruningCallback(
+                trial, "validation-rmse"
             )
             if estimator.__class__.__name__ == "XGBRegressor":
                 est = xgboost.train(
@@ -792,7 +825,7 @@ def _calc_best_estimator_optuna_univariate(
                     trial, estimator_params, param_key
                 )
             param["verbose"] = verbose
-            param["eval_metric"] = eval_metric
+            # param["eval_metric"] = eval_metric
 
             catest = catboost.CatBoostClassifier(**param)
             catest.fit(train_x, train_y, eval_set=[(valid_x, valid_y)], verbose=verbose)
@@ -807,7 +840,7 @@ def _calc_best_estimator_optuna_univariate(
                     trial, estimator_params, param_key
                 )
             param["verbose"] = verbose
-            param["eval_metric"] = eval_metric
+            # param["eval_metric"] = eval_metric
             lgbest = lightgbm.LGBMClassifier(**param)
             lgbest.fit(train_x, train_y, eval_set=[(valid_x, valid_y)], verbose=verbose)
             preds = lgbest.predict(valid_x)
@@ -821,7 +854,7 @@ def _calc_best_estimator_optuna_univariate(
                 )
 
             param["verbose"] = verbose
-            param["eval_metric"] = eval_metric
+            # param["eval_metric"] = performance_metric
             catest = catboost.CatBoostRegressor(**param)
             catest.fit(train_x, train_y, eval_set=[(valid_x, valid_y)], verbose=verbose)
             preds = catest.predict(valid_x)
@@ -834,7 +867,7 @@ def _calc_best_estimator_optuna_univariate(
                 )
 
             param["verbose"] = verbose
-            param["eval_metric"] = eval_metric
+            # param["eval_metric"] = eval_metric
             lgbest = lightgbm.LGBMRegressor(**param)
             lgbest.fit(train_x, train_y, eval_set=[(valid_x, valid_y)], verbose=verbose)
             preds = lgbest.predict(valid_x)
@@ -879,17 +912,26 @@ def _calc_best_estimator_optuna_univariate(
 
         if "classifier" in estimator.__class__.__name__.lower():
             accr = _calc_metric_for_single_output_classification(
-                valid_y, pred_labels, measure_of_accuracy
+                valid_y, pred_labels, performance_metric
             )
         if "regressor" in estimator.__class__.__name__.lower():
             accr = _calc_metric_for_single_output_regression(
-                valid_y, preds, measure_of_accuracy
+                valid_y, preds, performance_metric
             )
 
         return accr
 
-    study = optuna.create_study(direction="maximize", sampler=sampler, pruner=pruner)
-    study.optimize(objective, n_trials=number_of_trials, timeout=600)
+    # study = optuna.create_study(direction="maximize", sampler=sampler, pruner=pruner)
+    study.optimize(
+        objective,
+        n_trials=study_optimize_objective_n_trials,
+        timeout=study_optimize_objective_timeout,
+        n_jobs=study_optimize_n_jobs,
+        catch=study_optimize_catch,
+        callbacks=study_optimize_callbacks,
+        gc_after_trial=study_optimize_gc_after_trial,
+        show_progress_bar=study_optimize_show_progress_bar,
+    )
     trial = study.best_trial
 
     if (
